from .app import app, cli
from .compiler import compiler

__title__ = 'SnowLang'
__author__ = 'SnowballSH'
__license__ = 'MIT'
__version__ = '0.5.1.8'
